/// <reference types="node" />
import EventEmitter from 'events';
import type { InlineKeyboardMarkup, Message, MessageEntity, Params } from 'typegram';
import type { CallbackQueryRequest, ClientOptions, CommandRequest, MessageRequest } from './modules/telegramClient';
import { TelegramClient } from './modules/telegramClient';
interface WebHook {
    url: string;
}
interface StoredUpdate {
    time: number;
    botToken: string;
    updateId: number;
    messageId: number;
    isRead: boolean;
}
declare type BotIncommingMessage = Params<'sendMessage', never>[0];
declare type BotEditTextIncommingMessage = Params<'editMessageText', never>[0];
declare type BotEditReplyMarkupIncommingMessage = Params<'editMessageReplyMarkup', never>[0];
export interface StoredBotUpdate extends StoredUpdate {
    message: BotIncommingMessage;
}
interface StoredMessageUpdate extends StoredUpdate {
    message: MessageRequest;
}
interface StoredCommandUpdate extends StoredUpdate {
    message: CommandRequest;
    entities: MessageEntity[];
}
interface StoredCallbackQueryUpdate extends StoredUpdate {
    callbackQuery: CallbackQueryRequest;
    callbackId: number;
}
export declare type StoredClientUpdate = StoredMessageUpdate | StoredCommandUpdate | StoredCallbackQueryUpdate;
interface Storage {
    userMessages: StoredClientUpdate[];
    botMessages: StoredBotUpdate[];
}
export interface TelegramServerConfig {
    port: number;
    host: string;
    protocol: 'http' | 'https';
    storage: 'RAM' | string;
    storeTimeout: number;
}
export declare class TelegramServer extends EventEmitter {
    private webServer;
    private started;
    private updateId;
    private messageId;
    private callbackId;
    config: TelegramServerConfig & {
        apiURL: string;
    };
    storage: Storage;
    private cleanUpDaemonInterval;
    private server;
    private webhooks;
    constructor(config?: Partial<TelegramServerConfig>);
    static normalizeConfig(config: Partial<TelegramServerConfig>): {
        port: number;
        host: string;
        protocol: "http" | "https";
        storage: string;
        storeTimeout: number;
        apiURL: string;
    };
    getClient(botToken: string, options?: Partial<ClientOptions>): TelegramClient;
    addBotMessage(rawMessage: BotIncommingMessage, botToken: string): Message.TextMessage;
    editMessageText(rawMessage: BotEditTextIncommingMessage): void;
    editMessageReplyMarkup(rawMessage: BotEditReplyMarkupIncommingMessage): void;
    waitBotEdits(): Promise<void>;
    waitBotMessage(): Promise<void>;
    waitUserMessage(): Promise<void>;
    addUserMessage(message: MessageRequest): Promise<void>;
    addUserCommand(message: CommandRequest): Promise<void>;
    addUserCallback(callbackQuery: CallbackQueryRequest): Promise<void>;
    private getCommonFields;
    private addUserUpdate;
    messageFilter(message: StoredUpdate): boolean;
    cleanUp(): void;
    cleanUpDaemon(): void;
    getUpdatesHistory(token: string): (StoredBotUpdate | StoredMessageUpdate | StoredCallbackQueryUpdate)[];
    getUpdates(token: string): ({
        update_id: number;
        callback_query: {
            id: string;
            from: import("typegram").User;
            message: import("./modules/telegramClient").CommonMessage;
            data: string;
        };
        message?: undefined;
    } | {
        update_id: number;
        message: {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            channel_chat_created?: true | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            connected_website?: string | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            delete_chat_photo?: true | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            group_chat_created?: true | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            invoice?: import("typegram").Invoice | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            left_chat_member?: import("typegram").User | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            message_auto_delete_timer_changed?: import("typegram").MessageAutoDeleteTimerChanged | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            migrate_from_chat_id?: number | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            migrate_to_chat_id?: number | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            new_chat_members?: import("typegram").User[] | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            new_chat_photo?: import("typegram").PhotoSize[] | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            new_chat_title?: string | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            passport_data?: import("typegram").PassportData | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            proximity_alert_triggered?: import("typegram").ProximityAlertTriggered | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            pinned_message?: import("typegram").ReplyMessage | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            successful_payment?: import("typegram").SuccessfulPayment | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            supergroup_chat_created?: true | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            video_chat_scheduled?: import("typegram").VideoChatScheduled | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            video_chat_started?: import("typegram").VideoChatStarted | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            video_chat_ended?: import("typegram").VideoChatEnded | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            video_chat_participants_invited?: import("typegram").VideoChatParticipantsInvited | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            web_app_data?: import("typegram").WebAppData | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            animation?: import("typegram").Animation | undefined;
            document?: import("typegram").Document | undefined;
            media_group_id?: string | undefined;
            caption?: string | undefined;
            caption_entities?: MessageEntity[] | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            document?: import("typegram").Document | undefined;
            media_group_id?: string | undefined;
            caption?: string | undefined;
            caption_entities?: MessageEntity[] | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            audio?: import("typegram").Audio | undefined;
            media_group_id?: string | undefined;
            caption?: string | undefined;
            caption_entities?: MessageEntity[] | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            contact?: import("typegram").Contact | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            dice?: import("typegram").Dice | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            game?: import("typegram").Game | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            location?: import("typegram").Location | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            photo?: import("typegram").PhotoSize[] | undefined;
            media_group_id?: string | undefined;
            caption?: string | undefined;
            caption_entities?: MessageEntity[] | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            poll?: import("typegram").Poll | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            sticker?: import("typegram").Sticker | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            text: string;
            entities?: MessageEntity[] | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            venue?: import("typegram").Venue | undefined;
            location?: import("typegram").Location | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            video?: import("typegram").Video | undefined;
            media_group_id?: string | undefined;
            caption?: string | undefined;
            caption_entities?: MessageEntity[] | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            video_note?: import("typegram").VideoNote | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            voice?: import("typegram").Voice | undefined;
            caption?: string | undefined;
            caption_entities?: MessageEntity[] | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            channel_chat_created?: true | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            connected_website?: string | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            delete_chat_photo?: true | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            group_chat_created?: true | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            invoice?: import("typegram").Invoice | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            left_chat_member?: import("typegram").User | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            message_auto_delete_timer_changed?: import("typegram").MessageAutoDeleteTimerChanged | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            migrate_from_chat_id?: number | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            migrate_to_chat_id?: number | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            new_chat_members?: import("typegram").User[] | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            new_chat_photo?: import("typegram").PhotoSize[] | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            new_chat_title?: string | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            passport_data?: import("typegram").PassportData | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            proximity_alert_triggered?: import("typegram").ProximityAlertTriggered | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            pinned_message?: import("typegram").ReplyMessage | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            successful_payment?: import("typegram").SuccessfulPayment | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            supergroup_chat_created?: true | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            video_chat_scheduled?: import("typegram").VideoChatScheduled | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            video_chat_started?: import("typegram").VideoChatStarted | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            video_chat_ended?: import("typegram").VideoChatEnded | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            video_chat_participants_invited?: import("typegram").VideoChatParticipantsInvited | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            web_app_data?: import("typegram").WebAppData | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            animation?: import("typegram").Animation | undefined;
            document?: import("typegram").Document | undefined;
            media_group_id?: string | undefined;
            caption?: string | undefined;
            caption_entities?: MessageEntity[] | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            document?: import("typegram").Document | undefined;
            media_group_id?: string | undefined;
            caption?: string | undefined;
            caption_entities?: MessageEntity[] | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            audio?: import("typegram").Audio | undefined;
            media_group_id?: string | undefined;
            caption?: string | undefined;
            caption_entities?: MessageEntity[] | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            contact?: import("typegram").Contact | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            dice?: import("typegram").Dice | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            game?: import("typegram").Game | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            location?: import("typegram").Location | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            photo?: import("typegram").PhotoSize[] | undefined;
            media_group_id?: string | undefined;
            caption?: string | undefined;
            caption_entities?: MessageEntity[] | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            poll?: import("typegram").Poll | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            sticker?: import("typegram").Sticker | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            text: string;
            entities: MessageEntity[];
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            venue?: import("typegram").Venue | undefined;
            location?: import("typegram").Location | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            video?: import("typegram").Video | undefined;
            media_group_id?: string | undefined;
            caption?: string | undefined;
            caption_entities?: MessageEntity[] | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            video_note?: import("typegram").VideoNote | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        } | {
            message_id: number;
            chat: import("typegram").Chat.PrivateChat | import("typegram").Chat.GroupChat | import("typegram").Chat.SupergroupChat | import("typegram").Chat.ChannelChat;
            voice?: import("typegram").Voice | undefined;
            caption?: string | undefined;
            caption_entities?: MessageEntity[] | undefined;
            forward_from?: import("typegram").User | undefined;
            forward_from_chat?: import("typegram").Chat | undefined;
            forward_from_message_id?: number | undefined;
            forward_signature?: string | undefined;
            forward_sender_name?: string | undefined;
            forward_date?: number | undefined;
            is_automatic_forward?: true | undefined;
            reply_to_message?: import("typegram").ReplyMessage | undefined;
            via_bot?: import("typegram").User | undefined;
            edit_date?: number | undefined;
            has_protected_content?: true | undefined;
            author_signature?: string | undefined;
            reply_markup?: InlineKeyboardMarkup | undefined;
            from?: import("typegram").User | undefined;
            sender_chat?: import("typegram").Chat | undefined;
            date: number;
            botToken: string;
            text: string;
            entities: MessageEntity[];
        };
        callback_query?: undefined;
    })[];
    start(): Promise<void>;
    removeUserMessage(updateId: number): void;
    removeBotMessage(updateId: number): void;
    setWebhook(webhook: WebHook, botToken: string): void;
    deleteWebhook(botToken: string): void;
    deleteMessage(chatId: number, messageId: number): boolean;
    stop(): Promise<boolean>;
    private static formatUpdate;
    private static normalizeMessage;
}
export {};
